==> dxgl-src-0.1.1.zip: dxglcfg/resource.h <==
// DXGL
// Copyright (C) 2011 William Feely

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

#ifndef IDC_STATIC
#define IDC_STATIC (-1)
#endif

#define IDD_DXGLCFG                             103
#define IDI_DXGL                                107
#define IDI_DXGLSM                              109
#define IDI_STAR                                111
#define IDC_SYSMEMCACHE                         1001
#define IDC_HIGHRES                             1002
#define IDC_SORTMODES                           1003
#define IDC_UNCOMMONCOLOR                       1004
#define IDC_APPLY                               1015
#define IDC_APPS                                1037
#define IDC_ADD                                 1038
#define IDC_REMOVE                              1039
#define IDC_INSTALL                             1040
#define IDC_VIDMODE                             1041
#define IDC_SCALE                               1042
#define IDC_VSYNC                               1043
#define IDC_SHADER                              1044
#define IDC_BROWSESHADER                        1045
#define IDC_TEXFILTER                           1046
#define IDC_ANISO                               1047
#define IDC_MSAA                                1048
#define IDC_COLOR                               1049
#define IDC_ASPECT                              1050
#define IDC_AUDIO3D                             1051
#define IDC_AUDIOGLOBAL                         1052
#define IDC_INPUTGLOBAL                         1053
#define IDC_INPUTCFG                            1054
#define IDC_EXTRAMODES                          1055

==> dxgl-src-0.2.0.zip: dxglcfg/resource.h <==
// DXGL
// Copyright (C) 2011-2012 William Feely

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

#ifndef IDC_STATIC
#define IDC_STATIC (-1)
#endif

#define IDD_DXGLCFG                             103
#define IDI_DXGL                                107
#define IDI_DXGLSM                              109
#define IDI_STAR                                111
#define IDC_TEXFORMAT                           1001
#define IDC_HIGHRES                             1002
#define IDC_SORTMODES                           1003
#define IDC_UNCOMMONCOLOR                       1004
#define IDC_APPLY                               1015
#define IDC_APPS                                1037
#define IDC_ADD                                 1038
#define IDC_REMOVE                              1039
#define IDC_VIDMODE                             1041
#define IDC_SCALE                               1042
#define IDC_VSYNC                               1043
#define IDC_SHADER                              1044
#define IDC_BROWSESHADER                        1045
#define IDC_TEXFILTER                           1046
#define IDC_ANISO                               1047
#define IDC_MSAA                                1048
#define IDC_COLOR                               1049
#define IDC_ASPECT                              1050
#define IDC_EXTRAMODES                          1055
